@@ -2,6 +2,7 @@
 function(x, level=0.05, lhorz=TRUE, lvert=TRUE, lcol=2, llty=2, xlog=TRUE, xlab=paste("interval (", x$units.text, ")", sep=""), ylab="I (bits)", main=paste(x$type, "turnogram for:",x$data), sub=paste(x$fun, "/", x$proba), ...) {
 	# The next function actually draws the graph
 	turnogram.graph <- function(X, Level, Xlog, Lhorz, Lvert, Lcol, Llty, Xlab, Ylab, Main, Sub, ...) {
+		X$info[!is.finite(X$info)] <- NA
 		Ilevel <- -log(Level, base=2)
 		if (Xlog == TRUE) xlogstr <- "x" else xlogstr <- ""
 		if (X$proba == "two-tailed probability") {
@@ -13,10 +14,12 @@ function(x, level=0.05, lhorz=TRUE, lvert=TRUE, lcol=2, llty=2, xlog=TRUE, xlab=
 		}
 		if (X$type == "Simple") {
 			yrange.dat <- c(X$info, imin, 1.1*Ilevel)
-			yrange <- c(min(yrange.dat), max(yrange.dat))
+			yrange <- c(min(yrange.dat, na.rm = TRUE), max(yrange.dat, na.rm = TRUE))
 			plot(X$interval, X$info, type="l", log=xlogstr, ylim=yrange, xlab=Xlab, ylab=Ylab, main=Main, sub=Sub, ...)
 		} else {
-			yrange <- c(min(c(X$info.min, imin)), max(c(X$info.max, 1.1*Ilevel)))
+			X$info.min[!is.finite(X$info.min)] <- NA
+    	    X$info.max[!is.finite(X$info.max)] <- NA
+			yrange <- c(min(c(X$info.min, imin), na.rm = TRUE), max(c(X$info.max, 1.1 * Ilevel), na.rm = TRUE))
 			plot(X$interval, X$info, type="l", log=xlogstr, ylim=yrange, xlab=Xlab, ylab=Ylab, main=Main, sub=Sub, ...)
 			lines(X$interval, X$info.min)
 			lines(X$interval, X$info.max)
